#pragma once

#include <string>

/// \addtogroup public_api
/// @{

/// \brief Capitalizes all letters within in \p in.
///
/// \param in - The input to transform.
///
/// \return String containing all-capital version of \p in.
std::string capitalize(std::string in);

/// @}
// end of group public_api
